"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.KafkaDBRunner = void 0;
const kafka_1 = require("@testcontainers/kafka");
const db_runner_abstract_1 = require("./db-runner.abstract");
class KafkaDBRunner extends db_runner_abstract_1.DbRunnerAbstract {
    static startContainer(options) {
        const version = process.env.TEST_KAFKA_VERSION || options.version || '7.6.0';
        const container = new kafka_1.KafkaContainer(`confluentinc/cp-kafka:${version}`)
            .withKraft()
            .withEnvironment({
            KAFKA_TRANSACTION_STATE_LOG_REPLICATION_FACTOR: '1',
            KAFKA_TRANSACTION_STATE_LOG_MIN_ISR: '1',
            KAFKA_NUM_PARTITIONS: '1',
            KAFKA_DEFAULT_REPLICATION_FACTOR: '1',
        })
            .withExposedPorts(9093)
            .withStartupTimeout(10 * 1000);
        if (options.network) {
            container.withNetwork(options.network);
            container.withNetworkAliases('kafka');
        }
        if (options.volumes) {
            const binds = options.volumes.map(v => ({ source: v.source, target: v.target, mode: v.bindMode }));
            container.withBindMounts(binds);
        }
        return container.start();
    }
}
exports.KafkaDBRunner = KafkaDBRunner;
//# sourceMappingURL=kafka.js.map